@@ -2,14 +2,14 @@ dfToGeoJSON <-
 function(data, name, dest, lat.lon, overwrite) {
 	if(length(lat.lon)!=2) stop("'lat.lon' must be a vector of two: c(latitude, longitude)")
 	if(any(!is.numeric(lat.lon))) {
-		if(!any(names(data)==lat.lon[1])) stop("longitude column not found")
-		if(!any(names(data)==lat.lon[2])) stop("latitude column not found")
+		if(!any(names(data)==lat.lon[1])) stop("Longitude column not found")
+		if(!any(names(data)==lat.lon[2])) stop("Latitude column not found")
 		lat.lon <- c(which(names(data)==lat.lon[1]), which(names(data)==lat.lon[2]))
 	}
 	if(is.na(data[,lat.lon[1]]) || is.na(data[,lat.lon[2]])) stop("Coordinate columns not found")
 		
 	path <- paste0(file.path(dest, name), ".geojson")
-	if(file.exists(path) && !overwrite) stop("abort - file already exists\n")
+	if(file.exists(path) && !overwrite) stop("Abort - file already exists\n")
 	
 	# heading
 	cat("{", file=path, sep="\n")
@@ -25,7 +25,7 @@ function(data, name, dest, lat.lon, overwrite) {
 		if(length(data)>2) {
 			cat("      \"properties\": {", file=path, append=TRUE, sep="\n")
 			for(p in 3:length(data)) {
-				cat(paste("        \"", names(data)[p], "\": \"", data[f,p], "\"", sep=""), file=path, append=TRUE)
+				cat(paste0("        \"", names(data)[p], "\": \"", data[f,p], "\""), file=path, append=TRUE)
 				if(p==length(data)) cat("\n", file=path, append=TRUE)
 				else cat(",", file=path, append=TRUE, sep="\n")
 			}
@@ -35,7 +35,7 @@ function(data, name, dest, lat.lon, overwrite) {
 		# geometry
 		cat("      \"geometry\": {", file=path, append=TRUE, sep="\n")
 		cat("        \"type\": \"Point\",", file=path, append=TRUE, sep="\n")
-		cat(paste("        \"coordinates\": [", data[f,lat.lon[2]], ",", data[f,lat.lon[1]], "]", sep=""), file=path, append=TRUE, sep="\n")
+		cat(paste0("        \"coordinates\": [", data[f,lat.lon[2]], ",", data[f,lat.lon[1]], "]"), file=path, append=TRUE, sep="\n")
 		cat("      }", file=path, append=TRUE, sep="\n")
 		
 		if(f==nrow(data)) cat("    }", file=path, append=TRUE, sep="\n")
@@ -46,4 +46,4 @@ function(data, name, dest, lat.lon, overwrite) {
 	cat("}", file=path, append=TRUE, sep="\n")
 	
 	return(path)
-}
\ No newline at end of file
+}
