@@ -8,7 +8,6 @@ function(col, lwd, alpha, fill, fill.alpha, rad) {
 		else style <- append(style, paste("color: \"", getHex(col), "\"", sep=""))
 	}
 	if(!missing(lwd)) style <- append(style, paste("weight:", lwd))
-	#if(!missing(lty)) style <- append(style, paste("dashArray: \"", paste(toString(substring(lty, seq(1,nchar(lty),1), seq(1,nchar(lty),1))), sep=", "), "\"", sep=""))
 	if(!missing(alpha)) style <- append(style, paste("opacity:", alpha))
 	if(!missing(fill)) {
 		if(is.na(fill)) style <- append(style, "fill: false")
@@ -17,7 +16,7 @@ function(col, lwd, alpha, fill, fill.alpha, rad) {
 	if(!missing(fill.alpha)) style <- append(style, paste("fillOpacity:", fill.alpha))
 	if(!missing(rad)) style <- append(style, paste("radius:", rad))
 
-	if(is.null(style)) stop("no style parameters defined")
+	if(is.null(style)) stop("No style parameters defined")
 	attr(style, "style.type") <- "single"
 	return(style)
-}
\ No newline at end of file
+}
